//
//  ViewController.swift
//  2016Movies
//
//  Created by Malek T. on 7/27/16.
//  Copyright © 2016 Medigarage Studios LTD. All rights reserved.
//

import UIKit

class ViewController: UIViewController, UITableViewDataSource, UITableViewDelegate {
    // 1
    var expandedLabel: UILabel!
    var indexOfCellToExpand: Int!
    // 2
    var movies: [[String: AnyObject]]!
    var selectedMovie: [String: AnyObject]!
    var selectedMoviePhoto: UIImage!
    
    @IBOutlet var tableView: UITableView!
    override func viewDidLoad() {
        super.viewDidLoad()
        indexOfCellToExpand = -1
        tableView.dataSource = self
        tableView.delegate = self
        movies = [[String: AnyObject]]()
        let url = URL(string: "http://sweettutos.com/movies.json")
        let task = URLSession.shared().dataTask(with: url!) { (data:Data?, response: URLResponse?, error: NSError?) in
            if error == nil
            {
                do {
                    let results = try JSONSerialization.jsonObject(with: data!, options: .mutableLeaves) as! [String:AnyObject]
                    self.movies = results["movies"] as! [[String: AnyObject]]
                    DispatchQueue.main.async(execute: {
                        self.tableView.reloadData()
                    })
                }catch
                {
                    print("An error occurred")
                }
            }
        }
        task.resume()
    }
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func expandCell(sender: UITapGestureRecognizer)
    {
        let label = sender.view as! UILabel
        
        let cell: MovieCustomCell = tableView.cellForRow(at: IndexPath(row: label.tag, section: 0)) as! MovieCustomCell
        let movie = self.movies[label.tag]
        let description = movie["Description"] as! String
        cell.movieDescription.sizeToFit()
        cell.movieDescription.text = description
        expandedLabel = cell.movieDescription
        indexOfCellToExpand = label.tag
        tableView.reloadRows(at: [IndexPath(row: label.tag, section: 0)], with: .fade)
        tableView.scrollToRow(at: IndexPath(row: label.tag, section: 0), at: .top, animated: true)
    }
    //MARK: UITableViewDataSource
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "CellID") as! MovieCustomCell
        let movie = self.movies[indexPath.row]
        let photoURL = movie["Photo"] as! String
        let title = movie["Title"] as! String
        let intro = movie["Intro"] as! String
        cell.movieTitle.text = title
        cell.movieDescription.text = intro
        cell.movieDescription.tag = indexPath.row
        let tap = UITapGestureRecognizer(target: self, action: #selector(ViewController.expandCell(sender:)))
        cell.movieDescription.addGestureRecognizer(tap)
        cell.movieDescription.isUserInteractionEnabled = true
        // Download the photo using the SDWebImage library
        cell.moviePhoto.sd_setImage(with: URL(string: photoURL))
        return cell
    }
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.movies.count
    }
    //MARK: UITableViewDelegate
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if indexPath.row == indexOfCellToExpand
        {
            return 170 + expandedLabel.frame.height - 38
        }
        return 170
    }
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        selectedMovie = movies[indexPath.row]
        let cell = tableView.cellForRow(at: indexPath) as! MovieCustomCell
        selectedMoviePhoto = cell.moviePhoto.image
        self.performSegue(withIdentifier: "ShowDetails", sender: self)
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: AnyObject?) {
        let detailsVC = segue.destinationViewController as! DetailsViewController
        detailsVC.movie = selectedMovie
        detailsVC.photo = selectedMoviePhoto
    }
}

